@@ -35,6 +35,9 @@ FAILEDOPERATION_CVMUNEXPECTEDERROR = 'FailedOperation.CVMUnexpectedError'
 # 无该接口CAM权限。
 FAILEDOPERATION_CAMNOAUTH = 'FailedOperation.CamNoAuth'
 
+# 集群禁止删除。
+FAILEDOPERATION_CLUSTERFORBIDDENTODELETE = 'FailedOperation.ClusterForbiddenToDelete'
+
 # 集群未找到。
 FAILEDOPERATION_CLUSTERNOTFOUND = 'FailedOperation.ClusterNotFound'
 
@@ -59,9 +62,15 @@ FAILEDOPERATION_COMPONENTCLINETHTTP = 'FailedOperation.ComponentClinetHttp'
 # 创建CLS采集配置失败。
 FAILEDOPERATION_CREATECLSCONFIG = 'FailedOperation.CreateClsConfig'
 
+# 创建CLS索引失败。
+FAILEDOPERATION_CREATECLSINDEX = 'FailedOperation.CreateClsIndex'
+
 # 创建CLS日志集失败。
 FAILEDOPERATION_CREATECLSLOGSET = 'FailedOperation.CreateClsLogSet'
 
+# 创建CLS机器组失败。
+FAILEDOPERATION_CREATECLSMACHINEGROUP = 'FailedOperation.CreateClsMachineGroup'
+
 # 创建 CLS 主题失败。
 FAILEDOPERATION_CREATECLSTOPIC = 'FailedOperation.CreateClsTopic'
 
@@ -83,6 +92,9 @@ FAILEDOPERATION_DBRECORDNOTFOUND = 'FailedOperation.DbRecordNotFound'
 # 获得安全组配额失败。
 FAILEDOPERATION_DFWGETUSGQUOTA = 'FailedOperation.DfwGetUSGQuota'
 
+# 获取CLS采集配置失败。
+FAILEDOPERATION_GETCLSCONFIG = 'FailedOperation.GetClsConfig'
+
 # 查询主题集失败。
 FAILEDOPERATION_GETCLSLOGSET = 'FailedOperation.GetClsLogSet'
 
@@ -389,6 +401,9 @@ INVALIDPARAMETER_CIDRCONFLICTWITHVPCCIDR = 'InvalidParameter.CidrConflictWithVpc
 # 创建的路由与VPC下已存在的全局路由产生冲突。
 INVALIDPARAMETER_CIDRCONFLICTWITHVPCGLOBALROUTE = 'InvalidParameter.CidrConflictWithVpcGlobalRoute'
 
+# CIDR无效。
+INVALIDPARAMETER_CIDRINVALI = 'InvalidParameter.CidrInvali'
+
 # 参数错误，CIDR不符合规范。
 INVALIDPARAMETER_CIDRINVALID = 'InvalidParameter.CidrInvalid'
 
@@ -491,5 +506,8 @@ UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 # AS伸缩关闭导致无法开启CA。
 UNSUPPORTEDOPERATION_CAENABLEFAILED = 'UnsupportedOperation.CaEnableFailed'
 
+# 集群不支持开启 VPC-CNI 模式。
+UNSUPPORTEDOPERATION_CLUSTERNOTSUITENABLEVPCCNI = 'UnsupportedOperation.ClusterNotSuitEnableVPCCNI'
+
 # 非白名单用户。
 UNSUPPORTEDOPERATION_NOTINWHITELIST = 'UnsupportedOperation.NotInWhitelist'
